{ config, pkgs, ...}: {
  imports = [
    ./hardware-configuration.nix
    ../../common/variables.nix
    ../../common/system.nix
    ../../common/grub.nix
    ../../common/network.nix
    ../../common/user.nix
    ../../common/tailscale.nix
  ];

  nix.settings.experimental-features = [ "nix-command" "flakes" ];
  nix.settings.sandbox = "relaxed";

  nix.settings.substituters = [
    "https://cache.nixos.org/"
    "http://hemera.tempest.local"
  ];

  nix.settings.trusted-public-keys = [
    "hemera.tempest.local:Tb4edCxlB4YNGJNnVYrpNkTmG82tCChVNXdes33y2kY="
  ];

  networking.extraHosts = ''
    100.80.151.66 hemera hemera.tempest.local
  '';

  ashe.system.hostname = "nyx";
  ashe.system.disk = "/dev/vda";

  ashe.user.username = "rose";
  ashe.user.description = "Ashelyn Rose";
  ashe.user.packages = with pkgs; [
    neofetch
    bat
    lazygit
    tmux
    psmisc
  ];

  ashe.network.interface = "ens3";
  ashe.network.address = "104.168.211.198";
  ashe.network.prefix = 16;
  ashe.network.gateway = "104.168.218.1";
  ashe.network.nameservers = [ "8.8.8.8" ];

  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.11";
}
